package de.intevation.flys.artifacts.model;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.FLYSArtifact;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;

import org.apache.log4j.Logger;

/**
 * Facet of a MiddleBedHeight curve.
 */
public class MiddleBedHeightFacet extends DataFacet {

    private static Logger logger = Logger.getLogger(MiddleBedHeightFacet.class);


    public MiddleBedHeightFacet() {
        // required for clone operation deepCopy()
    }


    public MiddleBedHeightFacet(
        int         idx,
        String      name,
        String      description,
        ComputeType type,
        String      stateId,
        String      hash
    ) {
        super(idx, name, description, type, hash, stateId);
    }


    public Object getData(Artifact artifact, CallContext context) {
        logger.debug("Get data for middle bed height at index: " + index);

        FLYSArtifact flys = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult)
            flys.compute(context, hash, stateId, type, false);

        MiddleBedHeightData[] data = (MiddleBedHeightData[]) res.getData();

        return data[index];
    }


    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        MiddleBedHeightFacet copy = new MiddleBedHeightFacet();
        copy.set(this);
        copy.type    = type;
        copy.hash    = hash;
        copy.stateId = stateId;
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
